rnalysis.filtering.Filter
=========================

.. currentmodule:: rnalysis.filtering

.. autoclass:: Filter

   
   
   
    .. automethod:: __init__
    
    

   
.. autosummary::
    :toctree: .
    
    Filter.biotypes
    Filter.describe
    Filter.difference
    Filter.filter_biotype
    Filter.filter_by_attribute
    Filter.filter_percentile
    Filter.filter_top_n
    Filter.head
    Filter.intersection
    Filter.number_filters
    Filter.print_features
    Filter.save_csv
    Filter.sort
    Filter.split_by_attribute
    Filter.split_by_percentile
    Filter.symmetric_difference
    Filter.tail
    Filter.text_filters
    Filter.union
    
    